@@ -33,7 +33,7 @@ class APIRequestor(object):
             return sorts
 
     def request(self, method, url, headers=None, body=None, params=None, api_key=None):
-        if method not in ['GET', 'POST', 'PUT', 'DELETE']:
+        if method not in ['GET', 'POST', 'PUT', 'DELETE', 'PATCH']:
             raise APIConnectionError(
                 "Unrecognized HTTP method {method}. This may indicate a bug in the Whatify "
                 "internal bindings. Please contact support for assistance.".format(method=method)
@@ -55,6 +55,9 @@ class APIRequestor(object):
     def post(self, url, headers=None, body=None, params=None, api_key=None):
         return self.request("POST", url, headers, body, params, api_key)
 
+    def patch(self, url, headers=None, body=None, params=None, api_key=None):
+        return self.request("PATCH", url, headers, body, params, api_key)
+
     def get(self, url, headers=None, body=None, params=None, api_key=None):
         return self.request("GET", url, headers, body, params, api_key)
 
