@@ -200,7 +200,7 @@ class MyWhatify:
     @classmethod
     def train_model(cls, data_name, dataset_id, target_metric=TargetMetric.RECALL_MACRO, training_time_in_minutes=6,
                     cv_folds=3, ensemble_size=5, interpt_level=Interpt.EXPLAINABLE, max_models_num=None,
-                    wait=True, skip_if_exists=True):
+                    leaky_features=[], wait=True, skip_if_exists=True):
         with allure.step('On data_name: ' + data_name + ' ID: ' + str(dataset_id)
                          + ' training a model with target_metric: ' + str(target_metric.value)
                          + ' cv_folds: ' + str(cv_folds) + ' ensemble_size: ' + str(ensemble_size)
@@ -238,6 +238,7 @@ class MyWhatify:
                     n_folds=cv_folds,
                     max_models_num=int(max_models_num) if max_models_num else max_models_num,
                     interpretability_level=interpretability_level,
+                    leaky_features=leaky_features,
                     timeout=int(training_time_in_minutes) * 60, wait=wait, skip_if_exists=skip_if_exists
                 )
                 task_id = task['id']
